@@ -477,9 +477,9 @@ class RedisRoot:
                 if django_field.__class__ in field_mapping.keys():
                     redis_field = field_mapping[django_field.__class__]
 
-                print(django_field.__class__.name)
+                print(django_field.__class__.__name__)
                 redis_field = type(
-                    django_field.__class__.name,
+                    django_field.__class__.__name__,
                     (redis_field,),
                     get_allowed_params(django_field)
                 )
